if (FALSE) {
# Not run as this requires the installation of the HYDAT database
# plot a single station
stations <- c("05HH003")
p <- ch_gg_hydrographs(stations, daily = TRUE, instantaneous = TRUE)
# plot a group of stations in a region, as all appear to be responding to the same event
stations <- c("05CC001", "05CC011", "05CD006", "05CD007", "05CE002", "05CE006",
"05CE010", "05CE012", "05CE018", "05CE020", "05CG004", "05CG006")
p <- ch_gg_hydrographs(stations, daily = TRUE, instantaneous = FALSE,
common_dates = FALSE, start_date = "2011-06-01", end_date = "2011-06-30",
facets = TRUE, scales = "free_y", ncol= 3)
}
Run the code above in your browser using DataLab