Checks for outliers among the highest fifteen events, assumes the data are
normally distributed and uses the Grubbs test to determine if the highest
value is an outlier. If it is an outlier the next largest is tested until
the value is not an outlier, or 15 values have been tested.
Usage
ch_high_Grubbs_test(amax)
Value
result A vector of the same length as amax with a 1 for those values
that are high outliers else zero.