Learn R Programming

CSHShydRology (version 1.4.3)

ch_high_Grubbs_test: Grubbs test for high events

Description

Checks for outliers among the highest fifteen events, assumes the data are normally distributed and uses the Grubbs test to determine if the highest value is an outlier. If it is an outlier the next largest is tested until the value is not an outlier, or 15 values have been tested.

Usage

ch_high_Grubbs_test(amax)

Value

result A vector of the same length as amax with a 1 for those values that are high outliers else zero.

Arguments

amax

A vector of the annual maxima

Author

Paul Whitfield

Examples

Run this code
set.seed(1234)
x = rnorm(10)
x[11] <- 15
x[12] <- 35
ch_high_Grubbs_test(x)

Run the code above in your browser using DataLab